netapp_ontap.models.metrocluster_diagnostics_aggregate API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.metrocluster_diagnostics_aggregate`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class MetroclusterDiagnosticsAggregateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the MetroclusterDiagnosticsAggregate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `state GET`

    Status of diagnostic operation for this component.

    Valid choices:

    - ok
    - warning
    - not_run
    - not_applicable
  `summary GET`

    The summary field of the metrocluster_diagnostics_aggregate.

  `timestamp GET`

    Time of the most recent diagnostic operation for this component

    Example: 2016-03-10T22:35:16.000+0000